@@ -5,6 +5,7 @@ from hexbytes import HexBytes
 from client_sdk_python.module import (
     Module,
 )
+from eth_utils.hexadecimal import remove_0x_prefix
 from client_sdk_python.utils.encoding import parse_str
 from client_sdk_python.utils.transactions import send_obj_transaction, call_obj
 
@@ -402,7 +403,7 @@ class Ppos(Module):
         return receive
 
     def getDelegateReward(self, from_address, node_ids=None):
-        data = [rlp.encode(int(5100))]
+        data = [rlp.encode(int(5100)), rlp.encode(bytes.fromhex(remove_0x_prefix(from_address)))]
         if node_ids is not None:
             data = data.append(rlp.encode(node_ids))
         raw_data = call_obj(self, from_address, self.web3.delegateRewardAddress, data)
